@@ -202,10 +202,10 @@ class CommandLineInterface:
                 # message.
                 result['kwargs'][':help'] = True
         if result['kwargs'].get(':help'):
-            self.show(func)
+            self.show(func, show_func_name_in_title=bool(mode == 'group'))
         elif result['kwargs'].get(':helpx'):
             if func:
-                self.show(func)
+                self.show(func, show_func_name_in_title=bool(mode == 'group'))
             else:
                 self.show2()
                 # # self.show(None)
@@ -214,9 +214,12 @@ class CommandLineInterface:
         else:
             self.exec(func, result['args'].values(), result['kwargs'])
     
-    def show(self, func):
+    def show(self, func, **kwargs):
         """
         reference: [lib:click/core.py : BaseCommand.main()]
+        
+        kwargs:
+            show_func_name_in_title: bool[default True]
         """
         is_group: bool
         has_args: bool
@@ -230,15 +233,15 @@ class CommandLineInterface:
             console.print(
                 artist.draw_title(
                     prog_name=_detect_program_name(),
-                    command='<COMMAND>',
-                    options='[OPTIONS]',
-                    arguments=None,
+                    func_name='FUNCTION',
+                    args=(),
+                    kwargs=('...',)
                 ), justify='center'
             )
             
             console.print(
                 artist.draw_commands_panel((
-                    (v['cname'], v['desc'])
+                    (v['cname'], v['desc'])  # noqa
                     for v in self.commands.values()
                 ))
             )
@@ -266,11 +269,16 @@ class CommandLineInterface:
                 console.print(
                     artist.draw_title(
                         prog_name=_detect_program_name(),
-                        command=func_info['cname'],
-                        options='[OPTIONS]' if has_kwargs else None,
-                        arguments=tuple(
+                        func_name=func_info['cname']
+                        if kwargs.get('show_func_name_in_title', True)
+                        else '',
+                        args=tuple(
                             v['cname'] for v in func_info['args'].values()
                         ),
+                        kwargs=tuple(
+                            v['cname'].split(',', 1)[0]
+                            for v in func_info['kwargs'].values()
+                        )
                     ), justify='center'
                 )
                 if desc: console.print(indent(desc, ' '))
@@ -280,12 +288,17 @@ class CommandLineInterface:
                     '',
                     indent(artist.draw_title(
                         prog_name=_detect_program_name(),
-                        command=func_info['cname'],
-                        options='[OPTIONS]' if has_kwargs else None,
-                        arguments=tuple(
+                        func_name=func_info['cname']
+                        if kwargs.get('show_func_name_in_title', True)
+                        else '',
+                        args=tuple(
                             v['cname'] for v in func_info['args'].values()
                         ),
-                        serif_line=True,
+                        kwargs=tuple(
+                            v['cname'].split(',', 1)[0]
+                            for v in func_info['kwargs'].values()
+                        ),
+                        add_serif_line=True,
                     ), '    '),
                     indent(f'[grey74]{desc}[/]', '    '),
                     ''
@@ -361,15 +374,15 @@ class CommandLineInterface:
                 collect_renderables['title'] = Align.center(
                     artist.draw_title(
                         prog_name=_detect_program_name(),
-                        command='<COMMAND>',
-                        options='[OPTIONS]',
-                        arguments=None,
+                        func_name='FUNCTION',
+                        args=(),
+                        kwargs=('...',)
                     )
                 )
                 
                 collect_renderables['cmd_panel'] = (
                     artist.draw_commands_panel((
-                        (v['cname'], v['desc'])
+                        (v['cname'], v['desc'])  # noqa
                         for v in self.commands.values()
                     ))
                 )
@@ -395,11 +408,14 @@ class CommandLineInterface:
                 collect_renderables['title'] = Align.center(
                     artist.draw_title(
                         prog_name=_detect_program_name(),
-                        command=func_info['cname'],
-                        options='[OPTIONS]' if has_kwargs else None,
-                        arguments=tuple(
+                        func_name=func_info['cname'],
+                        args=tuple(
                             v['cname'] for v in func_info['args'].values()
                         ),
+                        kwargs=tuple(
+                            v['cname'].split(',', 1)[0]
+                            for v in func_info['kwargs'].values()
+                        ),
                     )
                 )
                 if desc:
@@ -444,7 +460,7 @@ class CommandLineInterface:
         
         parts = []  # noqa
         parts.append(show(None, show_logo=True))
-        parts.extend(show(v['func'], show_logo=False)
+        parts.extend(show(v['func'], show_logo=False)  # noqa
                      for v in self.commands.values())
         
         def render():
@@ -478,7 +494,7 @@ class CommandLineInterface:
             
             group = []
             for index, func_info in enumerate(self.commands.values()):
-                cmd_name = func_info['cname']
+                cmd_name = func_info['cname']  # noqa
                 group.append(tint(
                     f' {cmd_name} ',
                     f'b {palette.panel.command_highlight}'
